@@ -2,7 +2,7 @@
 
 import os
 from pathlib import Path
-from typing import Any, Callable
+from typing import Any, Callable, Generator
 
 import pandas as pd
 import pytest
@@ -13,7 +13,6 @@ from scripts import generate_sample_data
 @pytest.fixture(scope="session")
 def sample_data_dir(tmp_path_factory: pytest.TempPathFactory) -> Path:
     """Generate sample CSV files in an isolated directory for tests."""
-
     base_dir = tmp_path_factory.mktemp("sample_data")
     cwd = os.getcwd()
     os.chdir(base_dir)
@@ -28,7 +27,7 @@ def sample_data_dir(tmp_path_factory: pytest.TempPathFactory) -> Path:
 @pytest.fixture(scope="session")
 def load_sample_df(
     sample_data_dir: Path,
-) -> Callable[[str, Any], pd.DataFrame]:
+) -> Callable[..., pd.DataFrame]:
     """Return a loader that reads generated sample CSVs into dataframes."""
 
     def _loader(filename: str, **kwargs: Any) -> pd.DataFrame:
@@ -38,9 +37,8 @@ def load_sample_df(
 
 
 @pytest.fixture(autouse=True)
-def close_matplotlib_figures() -> None:
+def close_matplotlib_figures() -> Generator[None, None, None]:
     """Close any matplotlib figures created during a test."""
-
     yield
 
     import matplotlib.pyplot as plt
